Extraction functions for objects of class 'mtvgarch'.
# S3 method for mtvgarch
coef(object, spec = c("tvgarch", "garch", "tv", "cc"), ...)
# S3 method for mtvgarch
fitted(object, spec = c("tvgarch", "garch", "tv", "cc"),
as.zoo = TRUE, ...)
# S3 method for mtvgarch
logLik(object, ...)
# S3 method for mtvgarch
nobs(object, ...)
# S3 method for mtvgarch
plot(x, spec = c("tvgarch", "garch", "tv"), ...)
# S3 method for mtvgarch
predict(object, n.ahead = 10, newxtv = NULL,
newxreg = NULL, newindex = NULL, n.sim = 5000,
as.zoo = TRUE, verbose = FALSE, ...)
# S3 method for mtvgarch
print(x, ...)
# S3 method for mtvgarch
quantile(x, probs = 0.025, type = 7, as.zoo = TRUE, ...)
# S3 method for mtvgarch
residuals(object, as.zoo = TRUE, ...)
# S3 method for mtvgarch
summary(object, ...)
# S3 method for mtvgarch
toLatex(object, digits = 4, ...)
# S3 method for mtvgarch
vcov(object, spec = c("tvgarch", "garch", "tv", "cc"), ...)
parameter estimates.
fitted conditional variances and correlations.
optimised log-likelihood (normal density) values.
number of observations used in the estimation.
plots of the fitted conditional volatilities.
variance predictions. Column order differs when spillovers are allowed.
print of the estimation results.
fitted quantiles, i.e. the conditional standard deviation times the empirical quantile of the standardised innovations.
volatility standardised residuals.
summary of estimation results.
coefficient variance-covariance matrices.
an object of class 'mtvgarch'.
specifies whether the function should extract specific results. If "tv", extracts results for the TV component and if "garch" extracts results for the GARCH-X component of TV-GARCH-X model. If "tvgarch", extracts results for TV-GARCH-X model. Only relevant for TV-GARCH-X models. Otherwise, extracts results for GARCH-X models. If "cc", extracts results concerning the conditional correlations. "cc" is not valid in plot.mtvgarch().
an object of class 'mtvgarch'.
logical. If TRUE, then the returned result is of class
zoo.
integer that determines how many steps ahead predictions should be generated.
NULL or vector with the out-of-sample transition
variable. If NULL, out-of-sample component g equals intercept.g.
Only relevant for TV-GARCH-X models.
vector or matrix with the out-of-sample regressor values.
zoo-index for the out-of-sample predictions. If
NULL (default), then 1:n.ahead is used.
integer, the number of simulations.
logical. If TRUE, then the simulations - in
addition to the predictions - are returned.
vector of probabilities.
integer that determines the algorithm used to compute the
quantile, see quantile.
integer, the number of digits in the printed LaTeX code.
additional arguments.
Susana Campos-Martins
Cristina Amado and Timo Terasvirta (2013) Modelling volatility by variance decomposition, Journal of Econometrics 175, 142-153.
Christian Francq and Jean-Michel Zakoian (2016) Estimating multivariate volatility models equation by equation, J. R. Stat. Soc. Ser. B Stat. Methodol 78, 613-635.
Susana Campos-Martins and Genaro Sucarrat (2024) Modeling Nonstationary Financial Volatility with the R Package tvgarch, Journal of Statistical Software 108, 1-38.
mtvgarch,
mtvgarchSim,
tvgarch,
garchx,
zoo
set.seed(12345)
## Simulate from a bivariate CCC-TV(1)-GARCH(1,1) model (default):
mySim <- mtvgarchSim(n = 1500)
## Estimate a CCC-TV(1)-GARCH(1,1) model:
myEst <- mtvgarch(y = mySim)
## Print estimation results:
print(myEst)
## Extract and store conditional variances:
sigma2Est <- fitted(myEst)
## Plot:
plot(myEst)
## Generate predictions:
predict(myEst)
Run the code above in your browser using DataLab