Extraction functions (S3 methods) for objects of class 'tvgarch'.
# S3 method for tvgarch
coef(object, spec = c("tvgarch", "garch", "tv"), ...)
# S3 method for tvgarch
fitted(object, spec = c("tvgarch", "garch", "tv"),
as.zoo = TRUE, ...)
# S3 method for tvgarch
logLik(object, ...)
# S3 method for tvgarch
nobs(object, ...)
# S3 method for tvgarch
plot(x, spec = c("tvgarch", "garch", "tv"), ...)
# S3 method for tvgarch
predict(object, n.ahead = 10, newxtv = NULL,
newxreg = NULL, newindex = NULL, n.sim = 5000,
as.zoo = TRUE, verbose = FALSE, ...)
# S3 method for tvgarch
print(x, ...)
# S3 method for tvgarch
quantile(x, probs = 0.025, names = TRUE, type = 7,
as.zoo = TRUE, ...)
# S3 method for tvgarch
residuals(object, as.zoo = TRUE, ...)
# S3 method for tvgarch
summary(object, ...)
# S3 method for tvgarch
toLatex(object, digits = 4, ...)
# S3 method for tvgarch
vcov(object, spec = c("tvgarch", "garch", "tv"), ...)
parameter estimates.
fitted conditional variance.
optimised log-likelihood (normal density) value.
the number of observations used in the estimation.
plot of the fitted conditional volatility.
variance predictions.
print of the estimation results.
fitted quantiles, i.e. the conditional standard deviation times the empirical quantile of the standardised innovations.
volatility standardised residuals.
summary of estimation results.
coefficient variance-covariance matrix.
an object of class 'tvgarch'.
specifies whether the function should extract specific results. If "tv", extracts results for the TV component and if "garch" extracts results for the GARCH-X component of TV-GARCH-X model. If "tvgarch", extracts results for TV-GARCH-X model. Only relevant for TV-GARCH-X models. Otherwise, extracts results for GARCH-X models.
an object of class 'tvgarch'.
logical. If TRUE, then the returned result is of
class zoo.
integer that determines how many steps ahead predictions should be generated.
NULL or vector with the out-of-sample transition
variable. If NULL, out-of-sample component g equals intercept.g.
Only relevant for TV-GARCH-X models.
vector or matrix with the out-of-sample regressor values.
a zoo-index for the out-of-sample predictions. If
NULL (default), then 1:n.ahead is used.
integer, the number of simulations.
logical. If TRUE, then the simulations - in
addition to the predictions - are returned.
vector of probabilities.
logical, whether to return names or not.
integer that determines the algorithm used to compute the
quantile, see quantile.
integer, the number of digits in the printed LaTeX code.
additional arguments.
Susana Campos-Martins
Cristina Amado and Timo Terasvirta (2013) Modelling volatility by variance decomposition, Journal of Econometrics 175, 142-153.
Cristina Amado and Timo Terasvirta (2014) Modelling changes in the unconditional variance of long stock return series, Journal of Empirical Finance 25, 15-35.
Susana Campos-Martins and Genaro Sucarrat (2024) Modeling Nonstationary Financial Volatility with the R Package tvgarch, Journal of Statistical Software 108, 1-38.
tvgarchTest,
tvgarch,
tvgarchSim,
zoo
set.seed(123)
## Simulate from a TV(1)-GARCH(1,1) model (default):
ySim <- tvgarchSim(n = 1500)
## Estimate a TV(1)-GARCH(1,1) model:
yEst <- tvgarch(y = ySim)
## Print estimation results:
print(yEst)
## Extract and store conditional variances:
sigma2Est <- fitted(yEst)
## Plot:
plot(yEst)
## Generate predictions:
predict(yEst)
Run the code above in your browser using DataLab