Simulate from a multivariate multiplicative TV(s)-GARCH(p,q,r)-X model.
mtvgarchSim(n, m = 2, order.g = c(1,1), order.h = c(1,1,0, 1,1,0),
order.x = NULL, intercept.g = c(1.2,1), size = c(3,5), speed = c(10,25),
location = c(0.5,0.8), intercept.h = c(0.2,0.3), arch = c(0.10,0.05),
garch = c(0.80,0.90), asym = NULL, xtv = NULL, xreg = NULL, par.xreg = NULL,
R = c(1,0.6,0.6,1), dcc = FALSE, par.dcc = NULL, opt = 0, as.zoo = TRUE,
verbose = FALSE, innovations = NULL)An object of class 'zoo' (if as.zoo = TRUE), otherwise a matrix or a list
(if verbose = TRUE), with the simulated values.
integer.
integer indicating the dimenson of the multivariate series.
integer matrix with each row indicating the number of locations in each transition function of the TV components; m rows and max.s columns.
integer matrix with each row indicating the order.h for
each series; the first column controls the GARCH order, the second the ARCH
order and the third the asymmetry order of the GARCH-X components.
NULL or binary matrix indicating which xreg
variables should be included as covariates in the GARCH-X components. If
provided and xreg is NULL, volatility spillovers for the
selected series are included as covariates.
NULL or numeric vector.
NULL or numeric matrix containing the size coefficients.
Only relevant for TV-GARCH models.
NULL or numeric matrix containing the speed
coefficients. Only relevant for TV-GARCH models.
NULL or numeric matrix containing the location
coefficients; m rows and max.c columns. Only relevant for TV-GARCH models.
numeric matrix.
NULL or numeric matrix containing the ARCH coefficients.
NULL or numeric matrix containing the GARCH-type
coefficients.
NULL or numeric matrix containing the asymmetry-type
coefficients.
NULL or numeric vector, time series or zoo object to include
as the transition variable in the TV component. If NULL, calendar time,
scaled between 0 and 1, is used as the transition variable. Only relevant for
TV-GARCH models.
numeric vector, matrix, time series or zoo object to include as covariates in the GARCH-X component.
NULL or numeric matrix containing the covariates
initial coefficients.
matrix of (constant) conditional correlations.
logical. If TRUE, dynamic conditional correlations
are estimated. If FALSE (default), then the conditional correlations
are constant.
numeric vector containing the ARCH- and GARCH-type coefficients in the dynamic conditional correlations.
integer indicating whether the speed parameter in the TV component should be scaled. If 0, no scaling; if 1, speed/sd(xtv); if 2, exp(speed). Only relevant for TV-GARCH models.
logical. If TRUE, then the returned result is of
class zoo.
logical, if TRUE, the conditional variance and the
innovations are also returned.
NULL or numeric matrix with the innovations. If
NULL, then standard normal innovations are generated with
rnorm.
Susana Campos-Martins
mtvgarch,
tvgarch,
garchx,
zoo
set.seed(12345)
## Simulate from a bivariate CCC-TV(1)-GARCH(1,1) model (default):
mySim1 <- mtvgarchSim(n = 1500)
## Simulate from a bivariate CCC-TV(1)-GARCH(1,1)-X model
## (with volatility spillovers)
mySim2 <- mtvgarchSim(n = 1500, order.x = c(0,1,1,0), par.xreg =
c(0.03,0.04))
Run the code above in your browser using DataLab