Auxiliary functions used in the estimation of the univariate and multivariate TV(s)-GARCH(p,q,r)-X model. Not intended for the average user.
tv(speed, location, xtv = NULL, n = NULL, opt = 0,
order.g = NULL, as.zoo = TRUE, verbose = FALSE)
tvObj(par.g, fixed.par.g, xtv, opt, order.g, fixed.h, y, iter0, flag)
garchObj(par.h, xreg, order.h, fixed.g, y, flag)
tvgarchObj(par, fixed.par.g, y, order.g, xtv, opt, iter.fit.h, flag)The values of the objective function or fitted variance components.
NULL or numeric vector with the values of the
speed coefficients.
NULL or numeric vector with the values of the
location coefficients.
NULL or numeric vector, time series or
zoo
object to include as the transition variable in the TV component. If
NULL, a continuous variable bounded between 0 and 1 for n
observations is constructed and used as the transition variable.
integer indicating the number of observations of the
continuous transition variable bounded between 0 and 1.
integer, indicates whether the speed parameter in the TV
component should be scaled. If 0, no scaling; if 1, speed/sd(xtv); if 2,
exp(speed). For function tv(), the default is 0.
a scalar in tv() and an integer vector
of length s in tvObj() indicating the number of locations in each
transition function of the TV component. For function tv(), it defaults
to NULL.
logical. If TRUE, then the returned result is of
class zoo.
logical, if TRUE, the values of not only the
logistic transition function but also the transition variable are returned.
numeric vector with the values of the parameters in the TV
component. If iter0=TRUE, par.g takes the form
c(intercept.g, size, speed, location); if
iter0=FALSE, then par.g=c(speed,size,
location) and the values of the fixed parameters are provided using
fixed.par.g).
NULL or numeric vector with the values of the
parameters fixed in the TV component, i.e., intercept.g.
NULL or numeric vector with the values of the
parameters in the TV-GARCH-X model.
numeric vector, time series or zoo
containing the values of GARCH-X component).
numeric vector, time series or zoo object.
logical. If FALSE, some parameters in the TV
component are fixed during the iterative estimation.
integer. If 0, returns a numeric vector with the
values of the objective function; if 1 returns the the value of the objective
function; if 2, returns the fitted variance components.
numeric vector with the values of the parameters in the
GARCH-X component.
integer vector of the form c(p,q,r). The first
entry controls the GARCH order, the second the ARCH order and the third the
asymmetry order of the GARCH-X component.
numeric vector, times eries or zoo object to include as
covariates in the GARCH-X component.
numeric vector, time series or zoo
containing the values of TV component).
a list of class 'garchx'.
Susana Campos-Martins
tvgarch,
fitted.tvgarch,
residuals.tvgarch